@@ -15,7 +15,9 @@ import aws_cdk.aws_rds._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("cdk-serverless-lamp", "0.0.1", __name__[0:-6], "cdk-serverless-lamp@0.0.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "cdk-serverless-lamp", "1.0.3", __name__[0:-6], "cdk-serverless-lamp@1.0.3.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
